package sexp_pretty

  1. Overview
  2. Docs

Module Sexp_pretty.Sexp_with_layoutSource

Sourceval pp_formatter : Format.formatter writer

pp_formatter conf fmt sexp will mutate the fmt with functions such as set_formatter_tag_functions

Sourceval pp_buffer : Base.Buffer.t writer
Sourceval pp_out_channel : out_channel writer

pretty_string needs to allocate. If you care about performance, using one of the pp_* functions above is advised.